# The Dating Sim Engine was written by PyTom, 
# with updates added by Andrea Landaker (qirien),
# and contributions by Edmund Wilfong (Pneumonica)
#
# For support, see the Lemma Soft forums thread:
# http://lemmasoft.renai.us/forums/viewtopic.php?f=51&t=31571
#
# It is released under the MIT License - see DSE-LICENSE.txt
#
#
# This is the main part of the program, where you setup your schedule and
# the options for the user. You can change the stats, periods, and choices
# here; just make sure they match up with the events setup in
# dse-events.rpy.  You can even have different time periods (months, instead
# of times of day, for example).

# Set up a default schedule.
init python:
    register_stat("Social", "social", 0, 100)
    #register_stat("Intelligence", "int", 10, 100)
    register_stat("Art Skill", "art", 15, 100)
    register_stat("Gameing Skill," "gaming", 5, 100)
    register_stat("Stress Level", "stress", 10, 100)
    register_stat("Followers", "follow", 0, 10000)
    register_stat("Subscribers", "subs", 0, 10000)
    #Romance options
    register_stat("Guy 1 Affection", "guyone", 0, 100, hidden = True)
    register_stat("Guy 2 Affection", "guytwo", 0, 100, hidden = True)


    dp_period("Morning", "morning_act")
    dp_choice("Draw", "draw")
    dp_choice("Browse Youtube", "youtube")
    dp_choice("Browse Twitter", "twitter")
    
    dp_period("Noon", "noon_act")
    dp_choice("Attend Class", "class")
    dp_choice("Cut Class", "cut")
    
    # This is an example of an event that should only show up under special circumstances
    dp_choice("Go out with Guy One.", "Date", show="social >= 30 and guyone >= 100")

    dp_period("Afternoon", "afternoon_act")
    dp_choice("Study", "study")
    dp_choice("Browse Twitter", "twitter")
    dp_choice("Play Games", "play")

    dp_period("Evening", "evening_act")
    dp_choice("Draw", "draw")
    dp_choice("Play Games", "play")
    dp_choice("Browse Youtube", "youtube")

    
# This is the entry point into the game.
label start:

    # Initialize the default values of some of the variables used in
    # the game.
    $ day = 0

    # Show a default background.
    scene black

    # The script here is run before any event.

    "I'm just test text."
    
    "Yup"
    
    "More words to fill space."

    # We jump to day to start the first day.
    jump day


# This is the label that is jumped to at the start of a day.
label day:

    # Increment the day it is.
    $ day += 1

    # We may also want to compute the name for the day here, but
    # right now we don't bother.

    "It's day %(day)d."

    # Here, we want to set up some of the default values for the
    # day planner. In a more complicated game, we would probably
    # want to add and remove choices from the dp_ variables
    # (especially dp_period_acts) to reflect the choices the
    # user has available.

    $ morning_act = None
    $ afternoon_act = None
    $ evening_act = None
    $ narrator("What should I do today?", interact=False)
    window show
    

    # Now, we call the day planner, which may set the act variables
    # to new values. We call it with a list of periods that we want
    # to compute the values for.
    call screen day_planner(["Morning", "Noon", "Afternoon", "Evening"])
    window auto
    
    # We process each of the three periods of the day, in turn.
label morning:

    # Tell the user what period it is.
    centered "Morning"

    # Set these variables to appropriate values, so they can be
    # picked up by the expression in the various events defined below. 
    $ period = "morning"
    $ act = morning_act
    
    # Execute the events for the morning.
    call events_run_period

    
label noon:
    
    if check_skip_period():
        jump afternoon

    centered "Noon"
    
    "Time for school!"
 
    $ period = "noon"
    $ act = noon_act

    call events_run_period
    

label afternoon:

    # It's possible that we will be skipping the afternoon, if one
    # of the events in the morning jumped to skip_next_period. If
    # so, we should skip the afternoon.
    if check_skip_period():
        jump evening

    # The rest of this is the same as for the morning.

    centered "Afternoon"

    $ period = "afternoon"
    $ act = afternoon_act

    call events_run_period


label evening:
    
    # The evening is the same as the afternoon.
    if check_skip_period():
        jump night

    centered "Evening"
    
    "I'm so glad school is over... "

    $ period = "evening"
    $ act = evening_act
    
    call events_run_period


label night:

    # This is now the end of the day, and not a period in which
    # events can be run. We put some boilerplate end-of-day text
    # in here.

    centered "Night"

    "It's getting late, I should really to go to sleep."

    # We call events_end_day to let it know that the day is done.
    call events_end_day

    # And we jump back to day to start the next day. This goes
    # on forever, until an event ends the game.
    jump day
         

